@@ -82,7 +82,7 @@ class Exchange():
 
     def _adjust_emin(self):
         self.emin = self.G.find_energy_ingap(rbound=self.efermi-5.0)-self.efermi
-        print(f"A gap is found at {self.emin}, set emin to it.")
+        #print(f"A gap is found at {self.emin}, set emin to it.")
 
     def set_tbmodels(self, tbmodels):
         pass
@@ -564,6 +564,8 @@ class ExchangeNCL(Exchange):
                                                                   jatom])
             rhoRs.append(result[1])
         executor.close()
+        executor.join()
+        executor.clear()
         self.integrate(rhoRs, AijRs)
 
         self.get_rho_atom()
