@@ -4,6 +4,7 @@ from collections import defaultdict
 from ase.dft.kpoints import monkhorst_pack
 from shutil import rmtree
 import os
+import tempfile
 
 
 def eigen_to_G(evals, evecs, efermi, energy):
@@ -39,7 +40,7 @@ class TBGreen():
         efermi,  # efermi
         k_sym=False,
         use_cache=False,
-        cache_path='TB2J_results/cache'):
+        cache_path=None):
         """
         :param tbmodel: A tight binding model
         :param kmesh: size of monkhorst pack. e.g [6,6,6]
@@ -70,22 +71,26 @@ class TBGreen():
         ts = np.any(ts, axis=0)
         ts = np.where(ts)[0]
         istart, iend = ts[0], ts[-1] + 1
-        print(f"reducing nbands from {evals.shape[1]} to {len(ts)}")
         return evals[:, istart:iend], evecs[:, :, istart:iend]
 
     def find_energy_ingap(self, rbound, gap=1.0):
         return find_energy_ingap(self.evals, rbound, gap)
 
     def _prepare_cache(self):
-        path = self.cache_path
-        if not os.path.exists(path):
-            os.makedirs(path)
+        if self.cache_path is None:
+            if 'TMPDIR' in os.environ:
+                rpath=os.environ['TMPDIR']
+            else:
+                rpath='./TB2J_cache'
         else:
-            rmtree(path)
-            os.makedirs(path)
+            rpath=self.cache_path
+        if not os.path.exists(rpath):
+            os.makedirs(rpath)
+        self.cache_path=tempfile.mkdtemp(prefix='TB2J', dir=rpath)
+        print(f"Writting wavefunctions and Hamiltonian in cache {self.cache_path}")
 
     def clean_cache(self):
-        if os.path.exists(self.cache_path):
+        if (self.cache_path is not None) and os.path.exists(self.cache_path):
             rmtree(self.cache_path)
 
     def _prepare_eigen(self):
